@@ -16,18 +16,44 @@ from typing import Dict
 from ..models import MetaDatum, User
 
 
+def is_own_group(user, group):
+    return user.group.id == group.id
+
+
 def user_is_target(user, target_user):
     return user.id == target_user.id
 
 
 def has_group_rights(user, group):
-    return user.site_admin or (user.group_admin and user.group.id == group.id)
+    return user.site_admin or (user.group_admin and is_own_group(user, group))
 
 
 def is_power_grab(user, target_user):
     return not user.site_admin and target_user.site_admin
 
 
+def can_site_read(user):
+    return user.site_admin or user.site_read
+
+
+def view_user(user, target_user):
+    # Regular users shall only be able to request their own user and otherwise receive a 404.
+    # group_admin users shall be able to request information about all users in their group.
+    # site_read (!) and site_admin users shall be able to retrieve information about all users.
+    return any((
+        user_is_target(user, target_user),
+        has_group_rights(user, target_user.group),
+        can_site_read(user)
+    ))
+
+
+def view_group(user, group):
+    return any((
+        is_own_group(user, group),  # i assume, a 'normal' user can query their group's details regardless of group_admin status?
+        can_site_read(user)
+    ))
+
+
 def has_data_access(user, data_user_id, data_group_id=None, was_submitted=False):
     # if dataset was already submitted, the group must match, or the user must have site_read priviledges
     # if dataset was not yet submitted, the user must match
@@ -150,6 +176,10 @@ def update_user_name(user, target_user):
     ))
 
 
+def view_restricted_user_info(user, target_user):
+    return has_group_rights(user, target_user.group)
+
+
 def create_service(user):
     return user.site_admin
 
